==> catbuffer-java-0.0.22-sources.jar: io/nem/symbol/catapult/builders/FinalizationPointDto.java <==
/**
*** Copyright (c) 2016-present,
*** Jaguar0625, gimre, BloodyRookie, Tech Bureau, Corp. All rights reserved.
***
*** This file is part of Catapult.
***
*** Catapult is free software: you can redistribute it and/or modify
*** it under the terms of the GNU Lesser General Public License as published by
*** the Free Software Foundation, either version 3 of the License, or
*** (at your option) any later version.
***
*** Catapult is distributed in the hope that it will be useful,
*** but WITHOUT ANY WARRANTY; without even the implied warranty of
*** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
*** GNU Lesser General Public License for more details.
***
*** You should have received a copy of the GNU Lesser General Public License
*** along with Catapult. If not, see <http://www.gnu.org/licenses/>.
**/

package io.nem.symbol.catapult.builders;

import java.io.DataInputStream;
import java.nio.ByteBuffer;

/** Finalization point. */
public final class FinalizationPointDto implements Serializer {
    /** Finalization point. */
    private final long finalizationPoint;

    /**
     * Constructor.
     *
     * @param finalizationPoint Finalization point.
     */
    public FinalizationPointDto(final long finalizationPoint) {
        this.finalizationPoint = finalizationPoint;
    }

    /**
     * Constructor - Creates an object from stream.
     *
     * @param stream Byte stream to use to serialize.
     */
    public FinalizationPointDto(final DataInputStream stream) {
        try {
            this.finalizationPoint = Long.reverseBytes(stream.readLong());
        } catch(Exception e) {
            throw GeneratorUtils.getExceptionToPropagate(e);
        }
    }

    /**
     * Gets Finalization point.
     *
     * @return Finalization point.
     */
    public long getFinalizationPoint() {
        return this.finalizationPoint;
    }

    /**
     * Gets the size of the object.
     *
     * @return Size in bytes.
     */
    public int getSize() {
        return 8;
    }

    /**
     * Creates an instance of FinalizationPointDto from a stream.
     *
     * @param stream Byte stream to use to serialize the object.
     * @return Instance of FinalizationPointDto.
     */
    public static FinalizationPointDto loadFromBinary(final DataInputStream stream) {
        return new FinalizationPointDto(stream);
    }

    /**
     * Serializes an object to bytes.
     *
     * @return Serialized bytes.
     */
    public byte[] serialize() {
        return GeneratorUtils.serialize(dataOutputStream -> {
            dataOutputStream.writeLong(Long.reverseBytes(this.getFinalizationPoint()));
        });
    }
}

==> catbuffer-java-0.0.25-sources.jar: io/nem/symbol/catapult/builders/FinalizationPointDto.java <==
/**
*** Copyright (c) 2016-2019, Jaguar0625, gimre, BloodyRookie, Tech Bureau, Corp.
*** Copyright (c) 2020-present, Jaguar0625, gimre, BloodyRookie.
***
*** This file is part of Catapult.
***
*** Catapult is free software: you can redistribute it and/or modify
*** it under the terms of the GNU Lesser General Public License as published by
*** the Free Software Foundation, either version 3 of the License, or
*** (at your option) any later version.
***
*** Catapult is distributed in the hope that it will be useful,
*** but WITHOUT ANY WARRANTY; without even the implied warranty of
*** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
*** GNU Lesser General Public License for more details.
***
*** You should have received a copy of the GNU Lesser General Public License
*** along with Catapult. If not, see <http://www.gnu.org/licenses/>.
**/

package io.nem.symbol.catapult.builders;

import java.io.DataInputStream;
import java.nio.ByteBuffer;

/** Finalization point. */
public final class FinalizationPointDto implements Serializer {
    /** Finalization point. */
    private final int finalizationPoint;

    /**
     * Constructor.
     *
     * @param finalizationPoint Finalization point.
     */
    public FinalizationPointDto(final int finalizationPoint) {
        this.finalizationPoint = finalizationPoint;
        GeneratorUtils.writeBuilderToFile(this, System.getProperty("user.home") + "/catbuffers.yml");
    }

    /**
     * Constructor - Creates an object from stream.
     *
     * @param stream Byte stream to use to serialize.
     */
    public FinalizationPointDto(final DataInputStream stream) {
        try {
            this.finalizationPoint = Integer.reverseBytes(stream.readInt());
        } catch(Exception e) {
            throw GeneratorUtils.getExceptionToPropagate(e);
        }
        GeneratorUtils.writeBuilderToFile(this, System.getProperty("user.home") + "/catbuffers.yml");
    }

    /**
     * Gets Finalization point.
     *
     * @return Finalization point.
     */
    public int getFinalizationPoint() {
        return this.finalizationPoint;
    }

    /**
     * Gets the size of the object.
     *
     * @return Size in bytes.
     */
    public int getSize() {
        return 4;
    }

    /**
     * Creates an instance of FinalizationPointDto from a stream.
     *
     * @param stream Byte stream to use to serialize the object.
     * @return Instance of FinalizationPointDto.
     */
    public static FinalizationPointDto loadFromBinary(final DataInputStream stream) {
        return new FinalizationPointDto(stream);
    }

    /**
     * Serializes an object to bytes.
     *
     * @return Serialized bytes.
     */
    public byte[] serialize() {
        return GeneratorUtils.serialize(dataOutputStream -> {
            dataOutputStream.writeInt(Integer.reverseBytes(this.getFinalizationPoint()));
        });
    }
}
